Type: Package
Package: autoslider.core
Title: Slide Automation for Tables, Listings and Figures
Version: 0.3.2
Date: 2026-01-12
Authors@R: c(
    person("Joe", "Zhu", , "joe.zhu@roche.com", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0001-7566-2787")),
    person("Heng", "Wang", role = "aut"),
    person("Yinqi", "Zhao", role = "aut"),
    person("Bo", "Ci", role = "aut"),
    person("Liming", "Li", role = "aut"),
    person("Laura", "Wang", role = "ctb"),
    person("Xiaoli", "Duan", role = "aut"),
    person("Stefan Pascal", "Thoma", role = "aut"),
    person("Thomas", "Neitmann", role = "ctb"),
    person("Miles", "Almond", role = "aut"),
    person("Mahdi", "About", role = "ctb"),
    person("Kai", "Lim", role = "ctb"),
    person("Nolan", "Steed", role = "ctb"),
    person("Daoling", "Pang", role = "ctb"),
    person("Elisabeth", "Deutschmann", role = "ctb"),
    person("Chenkai", "Lv", role = "aut"),
    person("Nina", "Qi", role = "ctb"),
    person("Jasmina", "Uzunovic", role = "aut"),
    person("Yolanda", "Zhou", role = "aut")
  )
Description: The normal process of creating clinical study slides is that
    a statistician manually type in the numbers from outputs and a
    separate statistician to double check the typed in numbers. This
    process is time consuming, resource intensive, and error prone.
    Automatic slide generation is a solution to address these issues. It
    reduces the amount of work and the required time when creating slides,
    and reduces the risk of errors from manually typing or copying numbers
    from the output to slides. It also helps users to avoid unnecessary
    stress when creating large amounts of slide decks in a short time
    window.
License: Apache License 2.0
URL: https://github.com/insightsengineering/autoslider.core
BugReports: https://github.com/insightsengineering/autoslider.core/issues
Depends: R (>= 4.1.0)
Imports: assertthat (>= 0.2.1), checkmate (>= 2.2.0), cli (>= 3.6.3),
        dplyr (>= 1.1.3), flextable (>= 0.9.6), forcats (>= 1.0.0),
        formatters (>= 0.5.12), ggplot2 (>= 3.5.0), ggpubr (>= 0.6.0),
        grid, gridExtra (>= 2.3), gtsummary (>= 2.0.3), methods,
        officer (>= 0.7.0), rlang (>= 1.1.1), rlistings (>= 0.2.13),
        rtables (>= 0.6.15), rvg (>= 0.2.5), stringr (>= 1.5.0),
        survival, tern (>= 0.9.10), tidyr (>= 1.3.0), yaml (>= 2.3.7)
Suggests: data.table (>= 1.17.8), devtools (>= 2.4.5), ellmer (>=
        0.2.0), filters (>= 0.3.1), glue (>= 1.8.0), htmltools (>=
        0.5.8.1), httr (>= 1.4.7), knitr (>= 1.49), lubridate (>=
        1.9.3), mime (>= 0.12), nestcolor, purrr (>= 1.0.2), R.utils
        (>= 2.12.3), reticulate, rmarkdown (>= 2.23), rsvg (>= 0.3.4),
        svglite (>= 2.1.3), testthat (>= 3.3.0), TMB (>= 1.9.1), withr
VignetteBuilder: knitr
Config/Needs/verdepcheck: insightsengineering/formatters,
        tidyverse/magrittr, mllg/checkmate, rstudio/htmltools,
        gagolews/stringi, tidymodels/broom, cran/car, tidyverse/dplyr,
        davidgohel/flextable, yihui/knitr, r-lib/lifecycle,
        davidgohel/officer, Merck/r2rtf, rstudio/rmarkdown,
        therneau/survival, r-lib/testthat, tidyverse/tibble,
        tidyverse/tidyr, r-lib/withr, r-lib/xml2
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-12 04:10:19 UTC; rstudio
Author: Joe Zhu [cre, aut] (ORCID: <https://orcid.org/0000-0001-7566-2787>),
  Heng Wang [aut],
  Yinqi Zhao [aut],
  Bo Ci [aut],
  Liming Li [aut],
  Laura Wang [ctb],
  Xiaoli Duan [aut],
  Stefan Pascal Thoma [aut],
  Thomas Neitmann [ctb],
  Miles Almond [aut],
  Mahdi About [ctb],
  Kai Lim [ctb],
  Nolan Steed [ctb],
  Daoling Pang [ctb],
  Elisabeth Deutschmann [ctb],
  Chenkai Lv [aut],
  Nina Qi [ctb],
  Jasmina Uzunovic [aut],
  Yolanda Zhou [aut]
Maintainer: Joe Zhu <joe.zhu@roche.com>
Repository: CRAN
Date/Publication: 2026-01-12 06:50:03 UTC
Built: R 4.6.0; ; 2026-05-01 02:55:32 UTC; unix
