# Generated by roxygen2: do not edit by hand

S3method(print,decoratedGrob)
S3method(print,decoratedGrobSet)
S3method(to_flextable,Ddataframe)
S3method(to_flextable,VTableTree)
S3method(to_flextable,data.frame)
S3method(to_flextable,default)
S3method(to_flextable,dgtsummary)
S3method(to_flextable,dlisting)
S3method(to_flextable,gtsummary)
export(append_all_slides)
export(append_section_header_slides)
export(append_title_slides)
export(autoslider_dose_format)
export(autoslider_error)
export(autoslider_format)
export(black_format_tb)
export(blue_format)
export(build_table_header)
export(check_and_set_cutoff)
export(dec_paste)
export(decorate)
export(decorate.autoslider_error)
export(decorate.default)
export(decorate.ggplot)
export(decorate.grob)
export(decorate.gtsummary)
export(decorate.list)
export(decorate_outputs)
export(fastDoCall)
export(filter_spec)
export(format_3d)
export(format_date)
export(g_eg_slide)
export(g_lb_slide)
export(g_mean_general)
export(g_vs_slide)
export(generate_output)
export(generate_outputs)
export(generate_slides)
export(get_ai_notes)
export(get_ellmer_chat)
export(get_prompt_list)
export(get_template_filepath)
export(gt_t_dm_slide)
export(initialize_doc_original)
export(initialize_to_page)
export(l_ae_slide)
export(list_all_templates)
export(lyt_to_side_by_side)
export(lyt_to_side_by_side_two_data)
export(mutate_actarm)
export(na_replace)
export(new_round)
export(null_report)
export(orange_format)
export(perc_perc)
export(ph_with_img)
export(postprocessing_doc)
export(preprocess_t_dd)
export(preprocess_t_ds)
export(purple_format)
export(read_spec)
export(red_format)
export(s_surv_time_1)
export(save_output)
export(save_output.autoslider_error)
export(save_output.decoratedGrob)
export(save_output.decoratedGrobSet)
export(save_output.dgtsummary)
export(save_output.dlisting)
export(save_outputs)
export(slides_from_rds)
export(slides_preview)
export(t_ae_pt_diff_slide)
export(t_ae_pt_slide)
export(t_ae_pt_soc_diff_slide)
export(t_ae_pt_soc_slide)
export(t_ae_slide)
export(t_ae_summ_slide)
export(t_aesi_slide)
export(t_dd_slide)
export(t_dm_slide)
export(t_dor_slide)
export(t_ds_slide)
export(to_vector)
export(trial)
export(trim_perc)
export(trim_perc1)
export(use_template)
exportMethods(decorate)
import(assertthat)
import(dplyr)
import(flextable)
import(ggplot2)
import(officer)
import(rlistings)
import(rtables)
import(tern)
importFrom(assertthat,are_equal)
importFrom(assertthat,assert_that)
importFrom(assertthat,has_name)
importFrom(assertthat,is.string)
importFrom(assertthat,noNA)
importFrom(checkmate,assert_class)
importFrom(checkmate,assert_count)
importFrom(checkmate,assert_flag)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_numeric)
importFrom(cli,cat_bullet)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_at)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(forcats,fct_reorder)
importFrom(formatters,matrix_form)
importFrom(formatters,propose_column_widths)
importFrom(ggpubr,as_ggplot)
importFrom(grDevices,dev.off)
importFrom(grDevices,svg)
importFrom(graphics,title)
importFrom(grid,gpar)
importFrom(grid,grid.draw)
importFrom(grid,grid.newpage)
importFrom(grid,unit.pmax)
importFrom(gridExtra,arrangeGrob)
importFrom(gtsummary,add_p)
importFrom(gtsummary,modify_caption)
importFrom(gtsummary,tbl_summary)
importFrom(methods,formalArgs)
importFrom(methods,is)
importFrom(methods,new)
importFrom(officer,fortify_location)
importFrom(officer,layout_default)
importFrom(officer,ph_location_label)
importFrom(officer,set_notes)
importFrom(rlang,`:=`)
importFrom(rlang,abort)
importFrom(rvg,dml)
importFrom(stats,as.formula)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pt)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stringr,str_extract)
importFrom(stringr,str_to_title)
importFrom(survival,Surv)
importFrom(survival,coxph)
importFrom(survival,strata)
importFrom(survival,survdiff)
importFrom(survival,survfit)
importFrom(tern,control_coxph)
importFrom(tern,d_proportion)
importFrom(tern,format_xx)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(tidyr,unite)
importFrom(utils,assignInNamespace)
importFrom(utils,file.edit)
importFrom(utils,modifyList)
