# autoslider.core

<!-- start badges -->
[![Check
🛠](https://github.com/insightsengineering/autoslider.core/actions/workflows/check.yaml/badge.svg)](https://github.com/insightsengineering/autoslider.core/actions/workflows/check.yaml)
[![Docs 📚](https://github.com/insightsengineering/autoslider.core/actions/workflows/docs.yaml/badge.svg)](https://insightsengineering.github.io/autoslider.core/)
[![Release 🎈](https://github.com/insightsengineering/autoslider.core/actions/workflows/release.yaml/badge.svg)](https://github.com/insightsengineering/autoslider.core/releases)
[![Code Coverage
📔](https://raw.githubusercontent.com/insightsengineering/autoslider.core/_xml_coverage_reports/data/main/badge.svg)](https://raw.githubusercontent.com/insightsengineering/autoslider.core/_xml_coverage_reports/data/main/coverage.xml)
![GitHub forks](https://img.shields.io/github/forks/insightsengineering/autoslider.core?style=social)
![GitHub Repo stars](https://img.shields.io/github/stars/insightsengineering/autoslider.core?style=social)

![GitHub commit activity](https://img.shields.io/github/commit-activity/m/insightsengineering/autoslider.core)
![GitHub contributors](https://img.shields.io/github/contributors/insightsengineering/autoslider.core)
![GitHub last commit](https://img.shields.io/github/last-commit/insightsengineering/autoslider.core)
![GitHub pull requests](https://img.shields.io/github/issues-pr/insightsengineering/autoslider.core)
![GitHub repo size](https://img.shields.io/github/repo-size/insightsengineering/autoslider.core)
![GitHub language count](https://img.shields.io/github/languages/count/insightsengineering/autoslider.core)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Current Version](https://img.shields.io/github/r-package/v/insightsengineering/autoslider.core/main?color=purple\&label=package%20version)](https://github.com/insightsengineering/autoslider.core/tree/main)
[![Open Issues](https://img.shields.io/github/issues-raw/insightsengineering/autoslider.core?color=red\&label=open%20issues)](https://github.com/insightsengineering/autoslider.core/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc)
<!-- end badges -->

<img src="man/figures/autoslider_logo.png" align="right" width="180"/>

## Overview

`autoslider.core` creates a set of standard table templates that are often used in Study Results Endorsement Plan. It aims to reduce the amount of work when creating slides and avoid the duplicated effort between statisticians and programmers.

## Installation

`autoslider.core` is available on CRAN and you can install the latest released version with:

``` r
install.packages("autoslider.core")
```

or you can install the latest development version directly from GitHub by running the following:

``` r
# install.packages("pak")
pak::pak("insightsengineering/autoslider.core")
```
